@@ -98,7 +98,7 @@ impl Compiler {
                 }
                 Token::TestVarName(var) | Token::OpVarName(var) => {
                     current_var = var.clone();
-                    let to_front = if active_token == Token::TestVar {
+                    let to_front = if let Token::TestVarName(_) = token {
                         "score "
                     } else {
                         ""
@@ -215,7 +215,7 @@ impl Compiler {
                                 current_file!().push_str(&to_add[..]);
                             }
                             _ => {
-                                panic!(".= operator was tokenized for objective");
+                                panic!(":= operator was tokenized for objective");
                             }
                         }
                     }
